@@ -9,7 +9,7 @@ import (
 	"github.com/spf13/afero"
 	"github.com/suzuki-shunsuke/pinact/v3/pkg/controller/run"
 	"github.com/suzuki-shunsuke/pinact/v3/pkg/github"
-	"github.com/suzuki-shunsuke/pinact/v3/pkg/log"
+	"github.com/suzuki-shunsuke/urfave-cli-v3-util/log"
 	"github.com/urfave/cli/v3"
 )
 
@@ -62,7 +62,9 @@ func (r *runner) action(ctx context.Context, c *cli.Command) error {
 		Update:            c.Bool("update"),
 	})
 
-	log.SetLevel(c.String("log-level"), r.logE)
+	if err := log.Set(r.logE, c.String("log-level"), "auto"); err != nil {
+		return fmt.Errorf("configure logger: %w", err)
+	}
 	configFilePath := c.Args().First()
 	if configFilePath == "" {
 		configFilePath = c.String("config")
