@@ -8,6 +8,7 @@ import (
 	"io"
 	"net/http"
 	"os"
+	"regexp"
 	"strings"
 
 	"github.com/sirupsen/logrus"
@@ -27,6 +28,8 @@ type ParamRun struct {
 	Diff              bool
 	Stderr            io.Writer
 	Review            *Review
+	Includes          []*regexp.Regexp
+	Excludes          []*regexp.Regexp
 }
 
 type Review struct {
@@ -158,7 +161,7 @@ func (c *Controller) runWorkflow(ctx context.Context, logE *logrus.Entry, workfl
 
 func (c *Controller) handleParseLineError(ctx context.Context, logE *logrus.Entry, line *Line, gErr error) {
 	// Output error
-	c.logger.Output(levelError, "action isn't pinned", line, "")
+	c.logger.Output(levelError, "failed to handle a line: "+gErr.Error(), line, "")
 	if c.param.Review == nil {
 		// Output GitHub Actions error
 		if c.param.IsGitHubActions {
